@@ -6,7 +6,7 @@
  *          Robert Thurman.
  *
  *  Copyright (c) 1997 by The Geometry Center.
- *  Also Copyright (c) 2013 by Lloyd Wood.
+ *  Also Copyright (c) 2016 by Lloyd Wood.
  *
  *  This file is part of SaVi.  SaVi is free software;
  *  you can redistribute it and/or modify it only under
@@ -21,7 +21,7 @@
  *
  * coverage.c
  *
- * $Id: coverage.c,v 1.41 2013/05/05 05:19:25 lloydwood Exp $
+ * $Id: coverage.c,v 1.46 2016/01/09 04:21:17 lloydwood Exp $
  */
 #include <math.h>
 #include <stdlib.h>
@@ -91,6 +91,10 @@ coverage_on_cmd(int argc, char *argv[])
   CentralBody *pcb;
   Satellite_list sl;
 
+  if (Image_Height * Image_Width <= 0) {
+      return EMPTY_str;
+  }
+
   /* do memory allocations and initialize display first time only */
   if (!c_grid) {
     c_grid = create_grid(Image_Height, Image_Width);
@@ -207,6 +211,8 @@ map_on_cmd(int argc, char *argv[])
     update_coverage_display();
   }
 
+  redraw_earth(argc, argv);
+
   return EMPTY_str;
 }
 
@@ -219,6 +225,8 @@ map_off_cmd(int argc, char *argv[])
     update_coverage_display();
   }
 
+  redraw_earth(argc, argv);
+
   return EMPTY_str;
 }
 
@@ -368,6 +376,11 @@ get_coverage_type()
   return coverage_type;
 }
 
+int
+get_map_flag()
+{
+  return map_flag;
+}
 
 /*
  * Clear current coverage completely
