@@ -22,7 +22,7 @@
  *
  * Coverage visualization routines.
  *
- * $Id: coverage_vis.c,v 1.134 2016/01/09 04:21:17 lloydwood Exp $
+ * $Id: coverage_vis.c,v 1.136 2016/03/16 01:26:48 lloydwood Exp $
  */
 
 #include <math.h>
@@ -599,6 +599,11 @@ int
 coverage_dynamic_initialised(void)
 {
 
+  if (!geomview_stream_textures) {
+    error("Geomview does not support streaming images.");
+    return(FALSE);
+  }
+
   if (!dynamic_errors_reported) {
 #ifndef NO_ZLIB
     /* We can support compressed images. User may have set
@@ -619,11 +624,7 @@ coverage_dynamic_initialised(void)
     dynamic_errors_reported = TRUE;
   }
 
-  if (geomview_stream_textures) {
-    return(TRUE);
-  }
-
-  return;
+  return(TRUE);
 }
 
 void
