@@ -6,7 +6,7 @@
  *          Robert Thurman.
  *
  *  Copyright (c) 1997 by The Geometry Center.
- *  Also Copyright (c) 2013 by Lloyd Wood.
+ *  Also Copyright (c) 2016 by Lloyd Wood.
  *
  *  This file is part of SaVi.  SaVi is free software;
  *  you can redistribute it and/or modify it only under
@@ -22,7 +22,7 @@
  *
  * Routines for creating fancy earth model
  *
- * $Id: earth.c,v 1.39 2013/05/05 05:19:25 lloydwood Exp $
+ * $Id: earth.c,v 1.44 2016/01/09 04:21:17 lloydwood Exp $
  */
 #include <stdio.h>
 #include <math.h>
@@ -91,6 +91,35 @@ earth_delete_geom(void)
   earth_geom_exists = FALSE;
 }
 
+/*
+ * create_earth
+ */
+void
+create_earth(void)
+{
+  /* coverage map checkbox determines if we draw Earth with vector map or not. */
+  if (get_map_flag()) {
+     gv_create_geom("Central_Body", "central_t", "earth_vect_texture_sphere_h");
+  } else {
+     gv_create_geom("Central_Body", "central_t", "earth_h");
+  }
+}
+
+/*
+ * redraw_earth
+ */
+void
+redraw_earth(int argc, char *argv[])
+{
+  if (earth_on_flag) {
+    char *status = EMPTY_str;
+    if (geomview_module) gv_start();
+    status = earth_off_cmd(argc, argv);
+    status = earth_on_cmd(argc, argv);
+    if (geomview_module) gv_stop();
+  }
+}
+
 /*
  * earth_on_cmd
  *
@@ -118,7 +147,7 @@ earth_on_cmd(int argc, char *argv[])
 	earth_texture_loaded = gv_sendfile("oogl/earth_texture_h.oogl");
       }
       if (geomview_stream_textures && geomview_dynamic_texture_flag) {
-	if (coverage_projection == UNPROJECTED) {
+	if ((coverage_projection == UNPROJECTED)||(coverage_projection == UNPROJECTED_MASK)) {
 	  if (debug) error("texturemap sphere, dynamic unprojected map.");
 	  gv_sendfile("oogl/earth_coverage_unp_h.oogl");
 	  redraw_coverage_display();
@@ -135,16 +164,12 @@ earth_on_cmd(int argc, char *argv[])
 	  }
 	  geomview_dynamic_coverage = FALSE;
 	}
-	if (use_fancy_earth || use_simple_earth) {
-	  gv_create_geom("Central_Body", "central_t", "earth_vect_texture_sphere_h");
-	} else {
-	  gv_create_geom("Central_Body", "central_t", "earth_h");
-	}
+	create_earth();
       } else if (use_simple_earth) {
 	/* static texture - blue and gold map */
 	if (debug) error ("texturemap sphere, simple static Earth image.\n");
 	gv_sendfile("oogl/earth_h.oogl");
-	gv_create_geom("Central_Body", "central_t", "earth_vect_texture_sphere_h");
+	create_earth();
       } else if (use_fancy_earth) {
 	/* static texture - detailed texturemap */
 	if (debug) error ("texturemap sphere, detailed static Earth image.\n");
@@ -153,7 +178,7 @@ earth_on_cmd(int argc, char *argv[])
 	  error("Detailed Earth map requires later Geomview. Please upgrade.");
 	}
 	gv_sendfile("oogl/earth_fancy_h.oogl");
-	gv_create_geom("Central_Body", "central_t", "earth_vect_texture_sphere_h");
+	create_earth();
       } else {
 	if (debug) error ("texturemap sphere, do not draw detailed Earth.\n");
 	if (geomview_dynamic_coverage) {
@@ -166,14 +191,7 @@ earth_on_cmd(int argc, char *argv[])
       }
     } else if (earth_on_flag) {
       /* no texturing */
-      if (use_fancy_earth || use_simple_earth) {
-	if (debug) error ("ordinary sphere, detailed vector Earth.\n");
-        earth_texture_loaded = gv_sendfile("oogl/earth_vect_h.oogl");
-        gv_create_geom("Central_Body", "central_t", "earth_vect_sphere_h");
-      } else {
-        if (debug) error ("ordinary sphere.");
-        gv_create_geom("Central_Body", "central_t", "unit_sphere_h");
-      }
+      create_earth();
     }
     gv_stop();
   }
@@ -219,7 +237,6 @@ earth_off_cmd(int argc, char *argv[])
   return status;
 }
 
-
 /*
  * simple_on_cmd
  *
@@ -271,12 +288,7 @@ simple_off_cmd(int argc, char *argv[])
 
   use_simple_earth = FALSE;
 
-  if (earth_on_flag) {
-    if (geomview_module) gv_start();
-    status = earth_off_cmd(argc, argv);
-    status = earth_on_cmd(argc, argv);
-    if (geomview_module) gv_stop();
-  }
+  redraw_earth(argc, argv);
 
   return status;
 }
@@ -337,12 +349,7 @@ fancy_off_cmd(int argc, char *argv[])
 
   use_fancy_earth = FALSE;
 
-  if (earth_on_flag) {
-    if (geomview_module) gv_start();
-    status = earth_off_cmd(argc, argv);
-    status = earth_on_cmd(argc, argv);
-    if (geomview_module) gv_stop();
-  }
+  redraw_earth(argc, argv);
 
   return status;
 }
@@ -361,12 +368,7 @@ texture_on_cmd(int argc, char *argv[])
 
   texture_flag = TRUE;
 
-  if (earth_on_flag) {
-    if (geomview_module) gv_start();
-    status = earth_off_cmd(argc, argv);
-    status = earth_on_cmd(argc, argv);
-    if (geomview_module) gv_stop();
-  }
+  redraw_earth(argc, argv);
 
   return status;
 }
@@ -385,12 +387,7 @@ texture_off_cmd(int argc, char *argv[])
 
   texture_flag = FALSE;
 
-  if (earth_on_flag) {
-    if (geomview_module) gv_start();
-    status = earth_off_cmd(argc, argv);
-    status = earth_on_cmd(argc, argv);
-    if (geomview_module) gv_stop();
-  }
+  redraw_earth(argc, argv);
 
   return status;
 }
@@ -412,11 +409,8 @@ geomview_dynamic_texture_on_cmd(int argc, char *argv[])
     geomview_dynamic_texture_flag = TRUE;
   }
 
-  if (texture_flag && earth_on_flag) {
-    if (geomview_module) gv_start();
-    status = earth_off_cmd(argc, argv);
-    status = earth_on_cmd(argc, argv);
-    if (geomview_module) gv_stop();
+  if (texture_flag) {
+    redraw_earth(argc, argv);
   }
 
   return status;
@@ -434,16 +428,8 @@ geomview_dynamic_texture_off_cmd(int argc, char *argv[])
 
   geomview_dynamic_texture_flag = FALSE;
 
-  if (geomview_module && texture_flag) {
-    if (geomview_module) gv_start();
-
-    if (earth_on_flag) {
-      /* switch back to file-based Earth */
-      status = earth_off_cmd(argc, argv);
-      status = earth_on_cmd(argc, argv);
-    }
-
-    if (geomview_module) gv_stop();
+  if (texture_flag) {
+    redraw_earth(argc, argv);
   }
 
   return status;
