@@ -6,7 +6,7 @@
  *          Robert Thurman.
  *
  *  Copyright (c) 1997 by The Geometry Center.
- *  Also Copyright (c) 2013 by Lloyd Wood.
+ *  Also Copyright (c) 2016 by Lloyd Wood.
  *
  *  This file is part of SaVi.  SaVi is free software;
  *  you can redistribute it and/or modify it only under
@@ -22,7 +22,7 @@
  *
  * declaration and initialization of global variables.
  *
- * $Id: globals.c,v 1.42 2013/05/05 05:19:25 lloydwood Exp $
+ * $Id: globals.c,v 1.49 2016/01/09 04:21:17 lloydwood Exp $
  */
 
 #include <limits.h>
@@ -58,6 +58,9 @@ int footprints_flag = FALSE;
 /* sunlight is turned off by default */
 int sun_flag = FALSE;
 
+/* equatorial plane is turned off by default */
+int plane_flag = FALSE;
+
 /* fisheye default is not open, and location is not plotted in coverage */
 int fisheye_viewpoint_flag = FALSE;
 
@@ -74,6 +77,7 @@ int buttons_menu = FALSE;
 unsigned char * cyl_foreground = NULL;
 unsigned char * sin_foreground = NULL;
 unsigned char * unp_foreground = NULL;
+unsigned char * unp_mask_foreground = NULL;
 
 /* presumes default cylindrical projection */
 int Longitude_Center_Line = 0;
@@ -82,6 +86,9 @@ int coverage_display_center_longitude = 0;
 /* so we know if it has been set at command line. */
 int NUM_COLORS = 0;
 
+/* useful for elliptical orbits. */
+int min_transmit_altitude = 0;
+
 char * first_filename = NULL;
 
 /* empty string */
