@@ -20,7 +20,7 @@
  *
  * gv_utils.c
  *
- * $Id: gv_utils.c,v 1.33 2016/01/09 04:21:17 lloydwood Exp $
+ * $Id: gv_utils.c,v 1.35 2016/08/29 11:31:30 lloydwood Exp $
  */
 #include <stdio.h>
 #include <math.h>
@@ -32,7 +32,7 @@
 
 #include <netinet/in.h>
 
-/* #include <sys/select.h> *//* WARNING - not strictly correct !!! */
+#include <sys/select.h>
 /* extern int select(int, int *, int *, int *, struct timeval *); */
 
 #include "int_types.h"
@@ -452,7 +452,7 @@ gv_ready()
     gv_set_ready();
 
   if (select(fileno(gv_in) + 1, &fds, NULL, NULL, &poll) > 0) {
-    c = fgetc(gv_in);
+    c = (char)fgetc(gv_in);
     if (c != '\n')
       fprintf(stderr, "gv_ready: error, got char: %c (%d)\n", c, c);
     gv_ack = FALSE;
