@@ -6,7 +6,7 @@
  *          Robert Thurman.
  *
  *  Copyright (c) 1997 by The Geometry Center.
- *  Also Copyright (c) 2012 by Lloyd Wood.
+ *  Also Copyright (c) 2016 by Lloyd Wood.
  *
  *  This file is part of SaVi.  SaVi is free software;
  *  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
  *
  * coverage_vis.h
  *
- * $Id: coverage_vis.h,v 1.34 2012/01/01 02:48:41 lloydwood Exp $
+ * $Id: coverage_vis.h,v 1.38 2016/01/09 04:21:17 lloydwood Exp $
  */
 
 #ifndef _COVERAGE_VIS_H_
@@ -32,6 +32,7 @@
 /* bitmap of geographical boundaries for coverage */
 #define CYLINDRICAL_BITMAP_NAME "maps/world.cyl.pbm"
 #define UNPROJECTED_BITMAP_NAME "maps/world.unp.pbm"
+#define UNPROJECTED_MASK_BITMAP_NAME "maps/world-mask.unp.pbm"
 #define SPHERICAL_BITMAP_NAME "maps/world.sph.pbm"
 #define SPHERICAL_90_BITMAP_NAME "maps/world90W.sph.pbm"
 #define SINUSOIDAL_BITMAP_NAME "maps/world.sinu.pbm"
@@ -39,6 +40,7 @@
 
 #define CYLINDRICAL_LARGE_BITMAP_NAME "maps/world1024.cyl.pbm"
 #define UNPROJECTED_LARGE_BITMAP_NAME "maps/world1024.unp.pbm"
+#define UNPROJECTED_MASK_LARGE_BITMAP_NAME "maps/world-mask1024.unp.pbm"
 #define SPHERICAL_LARGE_BITMAP_NAME "maps/world1024.sph.pbm"
 #define SPHERICAL_90_LARGE_BITMAP_NAME "maps/world90W1024.sph.pbm"
 #define SINUSOIDAL_LARGE_BITMAP_NAME "maps/world1024.sinu.pbm"
