@@ -6,7 +6,7 @@
  *          Robert Thurman.
  *
  *  Copyright (c) 1997 by The Geometry Center.
- *  Also Copyright (c) 2012 by Lloyd Wood.
+ *  Also Copyright (c) 2016 by Lloyd Wood.
  *
  *  This file is part of SaVi.  SaVi is free software;
  *  you can redistribute it and/or modify it only under
@@ -22,7 +22,7 @@
  *
  * Global variable declarations
  *
- * $Id: globals.h,v 1.48 2012/01/01 02:48:41 lloydwood Exp $
+ * $Id: globals.h,v 1.56 2016/01/09 04:21:17 lloydwood Exp $
  */
 
 #ifndef _GLOBALS_H_
@@ -50,6 +50,7 @@ int geomview_compressed_images; /* FALSE if no zlib or -uncompressed. */
 int geomview_sun_lighting; /* TRUE if we trust geomview's light sources */
 
 int footprints_flag; /* TRUE if we want to see edges, inc sun terminator */
+int plane_flag; /* TRUE if we want to see equatorial plane */
 int sun_flag; /* TRUE if we want to see sun lighting */
 int fisheye_viewpoint_flag; /* TRUE if we want to plot location on coverage */
 
@@ -69,7 +70,8 @@ int orbit_model;
 
 /* We don't yet have a proper map for SINUSOIDAL centred on 0 deg lat. */
 typedef enum {
-  UNPROJECTED=0,
+  UNPROJECTED_MASK=0,
+  UNPROJECTED,
   CYLINDRICAL,
   SINUSOIDAL,
   SINUSOIDAL_90,
@@ -89,6 +91,8 @@ int coverage_projection;
 int Longitude_Center_Line;
 int coverage_display_center_longitude;
 
+int min_transmit_altitude ;
+
 /* number of colors in use by coverage panel map display */
 int NUM_COLORS;
 
@@ -101,6 +105,9 @@ unsigned int motion; /* TRUE to move satellites, FALSE to stop them */
 unsigned int reset; /* TRUE to reset satellites to original positions */
 unsigned int single_step; /* TRUE if take only one step */
 
+double equatorial_exclusion_angle; /* half-width/highest latitude of geo frequency exclusion belt */
+double parallels_angle; /* angle marked out in fisheye for parallel lines of latitude */
+
 double delta_t; /* time increment */
 double coverage_angle; /* angle for footprints */
 int coverage_type; /* mask elevation or the less-used cone angle */
