@@ -6,7 +6,7 @@
  *          Robert Thurman.
  *
  *  Copyright (c) 1997 by The Geometry Center.
- *  Also Copyright (c) 2012 by Lloyd Wood.
+ *  Also Copyright (c) 2016 by Lloyd Wood.
  *
  *  This file is part of SaVi.  SaVi is free software;
  *  you can redistribute it and/or modify it only under
@@ -22,7 +22,7 @@
  *
  * headers for the different functions
  *
- * $Id: savi.h,v 1.28 2012/01/01 02:48:41 lloydwood Exp $
+ * $Id: savi.h,v 1.32 2016/01/09 04:21:17 lloydwood Exp $
  */
 
 #ifndef _SAVI_H_
@@ -39,6 +39,7 @@ void gv_trans_list_create(Satellite_list);
 unsigned int gv_init(void);
 
 /* earth.c */
+void redraw_earth(int argc, char *argv[]);
 char *earth_off_cmd(int argc, char *argv[]);
 void earth_place(double t, const CentralBody *pcb);
 char *earth_on_cmd(int argc, char *argv[]);
@@ -131,6 +132,7 @@ char *print_access_on_cmd(int argc, char *argv[]);
 char *print_access_off_cmd(int argc, char *argv[]);
 char *map_on_cmd(int argc, char *argv[]);
 char *map_off_cmd(int argc, char *argv[]);
+int get_map_flag(void);
 int get_coverage_type(void);
 void tracks_compute(const Satellite_list sl, const CentralBody *pcb);
 char *tracks_on_cmd(int argc, char *argv[]);
