@@ -6,7 +6,7 @@
  *          Robert Thurman.
  *
  *  Copyright (c) 1997 by The Geometry Center.
- *  Also Copyright (c) 2013 by Lloyd Wood.
+ *  Also Copyright (c) 2016 by Lloyd Wood.
  *
  *  This file is part of SaVi.  SaVi is free software;
  *  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
  *
  * plane.c
  *
- * $Id: plane.c,v 1.12 2013/05/05 05:19:25 lloydwood Exp $
+ * $Id: plane.c,v 1.16 2016/01/09 04:21:17 lloydwood Exp $
  */
 #include <math.h>
 #include <stdlib.h>
@@ -49,6 +49,8 @@ plane_cmd(int argc, char *argv[])
   double Omega = atof(argv[3]);
   double m[4][4], ci, si, cO, sO;
 
+  plane_flag = TRUE;
+
   if (!geomview_module)
     return EMPTY_str;
 
@@ -71,8 +73,8 @@ plane_cmd(int argc, char *argv[])
   if (!plane_geom_exists) {
     gv_create_geom("Plane", "plane_t", "plane_h");
   }
-  gv_stop();
   plane_geom_exists = TRUE;
+  gv_stop();
 
   return EMPTY_str;
 }
@@ -85,14 +87,17 @@ plane_cmd(int argc, char *argv[])
 char *
 plane_off_cmd(int argc, char *argv[])
 {
-  if (!plane_geom_exists)
+  if (!plane_flag)
     return EMPTY_str;
 
-  plane_geom_exists = FALSE;
+  if(geomview_module) {
+    gv_start();
+    gv_delete_geom("Plane");
+    plane_geom_exists = FALSE;
+    gv_stop();
+  }
 
-  gv_start();
-  gv_delete_geom("Plane");
-  gv_stop();
+  plane_flag = FALSE;
 
   return EMPTY_str;
 }
