@@ -6,7 +6,7 @@
  *          Robert Thurman.
  *
  *  Copyright (c) 1997 by The Geometry Center.
- *  Also Copyright (c) 2013 by Lloyd Wood.
+ *  Also Copyright (c) 2016 by Lloyd Wood.
  *
  *  This file is part of SaVi.  SaVi is free software;
  *  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
  *
  * stats_utils.c
  *
- * $Id: stats_utils.c,v 1.38 2013/05/05 05:19:25 lloydwood Exp $
+ * $Id: stats_utils.c,v 1.44 2016/01/09 04:21:17 lloydwood Exp $
  */
 
 #include <stdio.h>
@@ -152,7 +152,7 @@ fill_grid(const Satellite_list SL, int current_projection, int fp_angle_type,
 {
   CartesianCoordinates c, u, v;
   Satellite_list sl;
-  double angle;
+  double angle, a;
 
   /* first satellite is special sunlight approximation */
   int sunlight = TRUE;
@@ -164,6 +164,10 @@ fill_grid(const Satellite_list SL, int current_projection, int fp_angle_type,
 
   for (sl = SL; NULL != sl; sl = sl->next) {
     if (sl->s->can_display_coverage) {
+      a = sl->s->x_S.r - pcb->radius;
+      if (a <= min_transmit_altitude) {
+         continue;
+      }
       footprint_circle(&c, &u, &v, fp_angle_type, angle,
 		       &(sl->s->x_C), pcb);
       orient_circle(sl->s->t, &c, &u, &v, pcb);
@@ -316,6 +320,7 @@ intensity_circle_footprint(CartesianCoordinates *pc, CartesianCoordinates *pu,
   /* compute phi increment so that we fill in each row of grid */
   switch (current_projection) {
   case UNPROJECTED:
+  case UNPROJECTED_MASK:
   case SINUSOIDAL:
   case SINUSOIDAL_90:
     dt = PI/(g->height-1)/norm(pu);
@@ -435,6 +440,7 @@ intensity_index(int grid_index[2], SphericalCoordinates *point,
 
   switch (current_projection) {
   case UNPROJECTED:
+  case UNPROJECTED_MASK:
     project_unprojected(proj, point);
     break;
   case SINUSOIDAL:
