@@ -20,7 +20,7 @@
 #
 # coverage.tcl
 #
-# $Id: coverage.tcl,v 1.166 2016/01/09 04:21:17 lloydwood Exp $
+# $Id: coverage.tcl,v 1.174 2016/03/29 01:53:57 lloydwood Exp $
 
 # Note: IM_W and IM_H are linked to C variables for the image size
 
@@ -64,12 +64,14 @@ proc coverage(init) {} {
 
     set coverage_projection $Projection(unprojected)
     set last_coverage_projection $coverage_projection
+
+    coverage(init_coldiv_coldec)
 }
 
 proc coverage(build) {} {
     global FONT COLOR COLDIV COLDEC coverage_flag no_access_flag tracks_flag \
 	coverage_proj_flag coverage_angle_flag project_tracks_flag map_flag \
-	coverage_projection coverage_angle IM_W IM_H im_x_offset im_y_offset \
+	coverage_projection coverage_angle im IM_W IM_H im_x_offset im_y_offset \
 	coverage_flag_dismissed tracks_flag_dismissed no_access_flag_dismissed \
 	coverage_display_center_longitude coverage_name \
 	sun_flag Fisheye NUM_COLORS NUM_COLORS_PREV
@@ -100,8 +102,11 @@ proc coverage(build) {} {
 	{"File" \
 	     {"Load satellites..." "load(build)"} \
 	     {"Save satellites as Tcl script..." "save(build)" "S"} \
+             {} \
+             {"Load new constellation TLEs from web..." "load_url_tle(build)"} \
 	     {} \
 	     {"Save map..." "coverage(save_map)" "M"} \
+             {"Save animation..." "coverage_frames(build)"} \
 	     {} \
 	     {"Load color shades..." "coverage(load_colors)"} \
 	     {"Save color shades..." "coverage(save_colors)"} \
@@ -926,10 +931,38 @@ proc coverage(decaycolor) {n} {
     coverage(update_decay)
 }
 
+proc coverage(save_map_handler) {filename} {
+    global im IM_H IM_W
+
+    # supported in Tcl 8.5 and 8.6
+    if {[string_ends "$filename" ".gif"] } {
+        set ext gif
+    }
+
+    # not supported in Tcl 8.5. Uncertain 8.6 support.
+    if {[string_ends "$filename" ".png"] } {
+        set ext png 
+    }
+
+    if {[string_ends "$filename" ".ppm"] } {
+        set ext ppm
+    }
+
+    $im write "$filename" -format $ext -from 0 0 $IM_W $IM_H
+    puts stderr "\nSaVi: saved map as $ext to $filename"
+}
+
 proc coverage(save_map) {} {
 
+    # {"SaVi coverage map (png)" {.png} }
+    # gives two-color images in 8.6 only, doesn't work in 8.5,
+    # and produces larger filesizes than gif.
+
+    # {"SaVi coverage map (ppm)" {.ppm} }
+    # works consistently, but is uncompressed.
     set types {
-	{"SaVi coverage map (gzipped)" {.ppm.gz} }
+        {"SaVi coverage map (gif)" {.gif} } \
+	{"SaVi coverage map (gzipped)" {.ppm.gz} } \
     }
 
     set filename [tk_getSaveFile -filetypes $types \
@@ -939,6 +972,11 @@ proc coverage(save_map) {} {
 
     set length [string length "$filename"]
 
+    if {[string_ends "$filename" ".png"] || [string_ends "$filename" ".gif"]} {
+       coverage(save_map_handler) $filename
+       return
+    }
+
     if {[string_ends "$filename" ".gz"]} {
 	set filename [string range "$filename" 0 [expr $length - 4]]
     }
@@ -949,9 +987,14 @@ proc coverage(save_map) {} {
 
     satellites COVERAGE_SAVE_MAP "$filename"
 
-    puts stderr "\nSaVi: saved map as raw ppm to $filename"
-    exec gzip -9 "$filename"
-    puts stderr "\nSaVi: gzip-compressed map to $filename.gz"
+    set gzip gzip
+
+    if {[catch {eval exec $gzip -9 "$filename"}]} {
+        puts stderr "\nSaVi: saved map as raw ppm to $filename"
+	puts stderr "      failed to compress map with $gzip."
+        return
+    }
+    puts stderr "\nSaVi: saved $gzip-compressed map to $filename.gz"
 }
 
 proc coverage(dismiss) {} {
