@@ -20,7 +20,7 @@
 #
 # fisheye.tcl
 #
-# $Id: fisheye.tcl,v 1.65 2016/01/09 04:21:17 lloydwood Exp $
+# $Id: fisheye.tcl,v 1.69 2016/05/30 11:22:25 lloydwood Exp $
 
 proc fisheye(init) {} {
     global fisheye_flag fisheye_reverse_view_flag fisheye_names_flag fisheye_numbers_flag \
@@ -81,6 +81,8 @@ proc fisheye(build) {} {
 	     {"Load satellites..." "load(build)"} \
 	     {"Save satellites as Tcl script..." "save(build)" "S"} \
 	     {} \
+             {"Load new constellation TLEs from web..." "load_url_tle(build)"} \
+             {} \
 	     {"Save fisheye as postscript..." fisheye(save)} \
 	     {} \
 	     {"Close window" "fisheye(dismiss)" "W"} \
@@ -154,12 +156,13 @@ proc fisheye(build) {} {
     main(rendering_menu) $fisheye_name.mbar.b4
 
     build_options_menu $fisheye_name.mbar.b5 \
+	{"Plot location on map" fisheye_viewpoint_flag } \
+	{} \
 	{"Show numbers" fisheye_numbers_flag} \
 	{"Show names" fisheye_names_flag} \
 	{"Show time in view" fisheye_times_flag} \
-	{"Plot location on map" fisheye_viewpoint_flag} \
 	{} \
- 	{"Show equator" plane_flag} \
+ 	{"Show stationary arc" plane_flag} \
 	{} \
 	{"Reverse fisheye view" fisheye_reverse_view_flag}
 
@@ -184,11 +187,11 @@ proc fisheye(build) {} {
     pack $cmdr
 
     build_Optionslist $cmd olist \
-	{"Show numbers" fisheye_numbers_flag} \
-	{"Show names" fisheye_names_flag} \
-	{"Show time in view" fisheye_times_flag} \
 	{"Plot location on map" fisheye_viewpoint_flag} \
-	{"Show equator" plane_flag}
+	{"Numbers" fisheye_numbers_flag} \
+	{"Names" fisheye_names_flag} \
+	{"Time in view" fisheye_times_flag} \
+	{"Stationary arc" plane_flag}
 
     set cmdb [build_StdFrame $cmd b]
 
