@@ -6,7 +6,7 @@
 #          Robert Thurman.
 #
 #  Copyright (c) 1997 by The Geometry Center.
-#  Also Copyright (c) 2013 by Lloyd Wood.
+#  Also Copyright (c) 2016 by Lloyd Wood.
 #
 #  This file is part of SaVi.  SaVi is free software;
 #  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
 #
 # geomview.tcl
 #
-# $Id: geomview.tcl,v 1.16 2013/05/05 05:19:26 lloydwood Exp $
+# $Id: geomview.tcl,v 1.31 2016/01/27 04:22:04 lloydwood Exp $
 
 proc geomview(new_camera) {} {
 
@@ -86,14 +86,6 @@ proc geomview(set_background_color) {} {
     geomview(puts) "(backcolor focus $geomr $geomg $geomb)"
 }
 
-proc geomview(reset_texture) {} {
-    global earth_flag
-
-    # recreate the Earth
-    set earth_flag 0
-    set earth_flag 1
-}
-
 proc geomview(wait) {} {
     satellites GV_WAIT
 
@@ -113,3 +105,46 @@ proc geomview(puts) v {
 
     satellites GV_SEND $v
 }
+
+proc geomview(update_texture) {} {
+    global geomview_module earth_flag
+
+    if {($geomview_module == 1)} {
+	geomview(begin)
+        # recreate the Earth if it exists
+	set flag $earth_flag
+	set earth_flag 0
+	if {$flag == 1} {
+            set earth_flag 1
+        }
+	geomview(end)
+    }
+}
+
+proc geomview(update_cones_footprints) {} {
+
+    global geomview_module cones_flag earth_flag footprints_flag
+
+    if {$geomview_module == 1} {
+	geomview(begin)
+
+        # recreate the Earth if it exists
+        set flag $earth_flag
+        set earth_flag 0
+        if {$flag == 1} {
+            set earth_flag 1
+        }
+	set flag $footprints_flag
+	set footprints_flag 0
+        if {$flag == 1} {
+	    set footprints_flag 1
+	}
+	set flag $cones_flag
+	set cones_flag 0
+        if {$flag == 1} {
+	    set cones_flag 1
+        }
+
+	geomview(end)
+    }
+}
