@@ -20,7 +20,7 @@
 #
 # main.tcl
 #
-# $Id: main.tcl,v 1.158 2016/01/17 23:24:21 lloydwood Exp $
+# $Id: main.tcl,v 1.162 2016/09/03 06:49:39 lloydwood Exp $
 
 proc main(build) {} {
     global main_name COLOR FONT TITLE geomview_module last_filename PLATFORM
@@ -58,9 +58,11 @@ proc main(build) {} {
 
     if {$geomview_module == 0} {
 	build_Menu $main_name.mbar.b0 \
-	    {"Load satellites..." "load(build)"} \
+	    {"Load more satellites..." "load(build)"} \
 	    {"Save satellites as Tcl script..." "save(build)" "S"} \
 	    {} \
+            {"Load new constellation TLEs from web..." "load_url_tle(build)"} \
+	    {} \
 	    {"Quit" "main(exit)" "Q"}
 	build_Menu $main_name.mbar.b2 \
 	    {"Global coverage..." "coverage(build)" "G"} \
@@ -77,6 +79,8 @@ proc main(build) {} {
 	build_Menu $main_name.mbar.b0 \
 	    {"Load satellites..." "load(build)"} \
 	    {"Save satellites as Tcl script..." "save(build)" "S"} \
+            {} \
+            {"Load new constellation TLEs from web..." "load_url_tle(build)"} \
 	    {} \
 	    {"Save Geomview camera screenshots..." "no_frames(build)"} \
 	    {"Save Geomview print rendering..." "snapshot(build)"} \
@@ -267,7 +271,6 @@ proc main(rendering_menu) {submenu} {
 	    {"Show central body" earth_flag} \
 	    {"Use simple Earth map" simple_earth_flag} \
 	    {"Use detailed Earth map" fancy_earth_flag} \
-	    {"Texture mapping" texture_flag} \
 	    {} \
     	    {"Animate in Geomview" geomview_flag}
     } else {
@@ -730,6 +733,7 @@ proc main(load_file) {filename} {
     if {[string_ends "$filename" ".tle"]} {
 	set last_filename "$filename"
 	# tle file
+        # if sunlight is on should really turn it off as misleading.
 	tle_file_input "$filename"
     } elseif {[string_ends "$filename" ".tcl"]} {
 	set last_filename "$filename"
